import { BaseEntity, Column, CreateDateColumn, Entity, ManyToOne, OneToMany, PrimaryGeneratedColumn, UpdateDateColumn } from 'typeorm'
import { User } from './User'
import { CashierStatus } from '../Common'
import { Expense } from './Expense'
import { Sale } from './Sale'

@Entity({ name: 'cashiers' })
export class Cashier extends BaseEntity {
    @PrimaryGeneratedColumn()
    id: number

    @Column({ type: 'decimal', precision: 8, scale: 2 })
    initialBalance: number

    @Column({ type: 'timestamp', nullable:true })
    closingDatetime: string

    @Column({ type: 'decimal', precision: 8, scale: 2, nullable:true})
    unbanlance: number

    @Column({ nullable: true})
    observation: string

    totalExpense: number

    @Column({ type: 'enum', enum: CashierStatus, default: CashierStatus.OPENING })
    status: CashierStatus

    @CreateDateColumn()
    createdAt: Date

    @UpdateDateColumn()
    updatedAt: Date

    @ManyToOne(() => User, (user) => user.cashiers)
    user: User

    @OneToMany(() => Expense, (expense) => expense.cashier)
    expenses: Expense[]

    @OneToMany(() => Sale, (sale) => sale.cashier)
    sales: Sale[]
}