import { BaseEntity, Column, CreateDateColumn, Entity, ManyToOne, OneToMany, PrimaryGeneratedColumn, UpdateDateColumn } from 'typeorm'
import { Unit } from './Unit'
import { Brand } from './Brand'
import { Subcategory } from './Subcategory'
import { Feature } from './Features'
import { ProductSale } from './ProductSale';

@Entity({ name: 'products' })
export class Product extends BaseEntity {
    @PrimaryGeneratedColumn()
    id: number

    @Column({ type: 'varchar', length: 10, unique: true })
    sku: string

    @Column({ type: 'varchar', length: 200, unique: true })
    name: string

    @Column({ nullable: true })
    imageUrl: string

    @Column({ nullable: true, unique:true })
    slug: string

    @Column({ type: 'decimal', precision: 8, scale: 2 })
    cost: number

    @Column({ type: 'decimal', precision: 5, scale: 2 })
    utility: number

    @Column({ type: 'decimal', precision: 8, scale: 2 })
    price: number

    @Column({ type: 'integer' })
    stock: number

    @Column({ type: 'integer' })
    stockMin: number

    @Column({ type: 'decimal', precision: 5, scale: 2 })
    bulkDiscount: number

    @CreateDateColumn()
    createdAt: Date

    @UpdateDateColumn()
    updatedAt: Date

    @ManyToOne(() => Unit, (unit) => unit.products)
    unit: Unit

    @ManyToOne(() => Brand, (brand) => brand.products)
    brand: Brand

    @ManyToOne(() => Subcategory, (subcategory) => subcategory.products)
    subcategory: Subcategory

    @OneToMany(() => Feature, (feature) => feature.product)
    features: Feature[]

    @OneToMany(() => ProductSale, productSale => productSale.product)
    items: ProductSale[]
}