import { BaseEntity, Column, CreateDateColumn, Entity, ManyToOne, OneToMany, PrimaryGeneratedColumn, UpdateDateColumn } from 'typeorm'
import { Customer } from './Customer'
import { Cashier } from './Cashier'
import { ProductSale } from './ProductSale'
import { InvoceTypes } from '../Common'

@Entity({ name: 'sales' })
export class Sale extends BaseEntity {
    @PrimaryGeneratedColumn()
    id: number

    @Column({ type: 'varchar', length: 15 })
    invoceNumber: string

    @Column({ type: 'enum', enum: InvoceTypes })
    invoceType: InvoceTypes

    @Column({ type: 'decimal', precision: 8, scale: 2 })
    igv: number

    @Column({ type: 'decimal', precision: 8, scale: 2 })
    saleAmount: number

    @Column()
    cashierId: number

    @Column()
    customerId: number

    @CreateDateColumn()
    createdAt: Date

    @UpdateDateColumn()
    updatedAt: Date

    @ManyToOne(() => Customer, (customer) => customer.sales, { nullable: false })
    customer: Customer

    @ManyToOne(() => Cashier, (cashier) => cashier.expenses, { nullable: false })
    cashier: Cashier

    @OneToMany(() => ProductSale, productSale => productSale.sale)
    items: ProductSale[]
}