import { EntitySubscriberInterface, EventSubscriber, InsertEvent, UpdateEvent } from 'typeorm'
import { Category } from '../entities/Category'
import slugify from 'slugify'

@EventSubscriber()
export class CategorySubscriber implements EntitySubscriberInterface<Category> {

    listenTo() {
        return Category
    }

    /**
     * Called before entity insertion.
     */
    async beforeInsert(event: InsertEvent<Category>) {
        await this.generateSlug(event.entity)
    }

    /**
     * Called before entity update.
     */
    async beforeUpdate(event: UpdateEvent<Category>) {
        // Ensure the entity is of type Category
        if (event.entity instanceof Category) {
            await this.generateSlug(event.entity)
        }
    }

    /**
     * Generate the slug based on the name.
     */
    private async generateSlug(category: Category) {
        category.slug = slugify(category.name, { lower: true })
    }
}
