import { EntitySubscriberInterface, EventSubscriber, InsertEvent, UpdateEvent } from 'typeorm'
import { Subcategory } from '../entities/Subcategory'
import slugify from 'slugify'

@EventSubscriber()
export class CategorySubscriber implements EntitySubscriberInterface<Subcategory> {

    listenTo() {
        return Subcategory
    }

    /**
     * Called before entity insertion.
     */
    async beforeInsert(event: InsertEvent<Subcategory>) {
        await this.generateSlug(event.entity)
    }

    /**
     * Called before entity update.
     */
    async beforeUpdate(event: UpdateEvent<Subcategory>) {
        // Ensure the entity is of type Category
        if (event.entity instanceof Subcategory) {
            await this.generateSlug(event.entity)
        }
    }

    /**
     * Generate the slug based on the name.
     */
    private async generateSlug(subcategory: Subcategory) {
        subcategory.slug = slugify(subcategory.name, { lower: true })
    }
}
