import { Request, Response, NextFunction } from "express"
import { QueryFailedError } from "typeorm"
import { failed } from "./responseHandler"


export const logErrors = (error: any, req: Request, res: Response, next: NextFunction) => {
    console.error(error)
    next(error)
}

export const boomErrorHandler = (error: any, req: Request, res: Response, next: NextFunction) => {
    if (error.isBoom) {
        const { output } = error
        failed(res, output.statusCode, output.payload.message, output.payload.error)
    }
    next(error)
}

export const ormErrorHandler = (err: any, req: Request, res: Response, next: NextFunction) => {
    if (err instanceof QueryFailedError) {
        failed(res, 500, 'Error en la base de datos', {
            message: err.message,
            detail: err.driverError.detail,
            code: err.driverError.code
        })
    }

    next()
}

export const errorHandler = (err: any, req: Request, res: Response, next: NextFunction) => {
    failed(res, 500, err.message, { stack: err.stack })
}