import { Response } from 'express';

export interface ResponseInterface {
    type: 'success' | 'failed',
    message: string,
    [key: string]: any
}

export const success = (res: Response, data: any, message?: string, statusCode?: number): void  => {
    const defaultMessage = message || "'Solicitud ha tenido éxito'"
    const defaultStatusCode  = statusCode || 200
    
    const responseBody: ResponseInterface = {
        type: 'success',
        message: defaultMessage,
        ...data,
    };

    res.status(defaultStatusCode).json(responseBody);
}

export const failed = (res: Response, statusCode: number, message: string, error?: any): void => {
    const defaultStatusCode = statusCode || 500

    const responseBody: ResponseInterface = {
        type: 'failed',
        message,
        error,
    };

    res.status(defaultStatusCode).json(responseBody);
}
