import { FindManyOptions, ILike } from 'typeorm'
import boom from '@hapi/boom'
import { Account } from '@/db/entities/Account'
import { CreateAccountOptions, CloseAccountOptions } from './accountSchema'
import { QueryCommonOptions } from '@/utils/commonSchema'
import { getUser } from '../users/userController'
import { AccountStatus } from '@/db/entities/CommonOptions'

export const getAccounts = async (query: QueryCommonOptions) => {
    const { skip, take, search, sortKey, sortOrder } = query
    const queryOptions = {
        order: {
            id: 'DESC'
        },
        skip: skip,
        take: take
    } as FindManyOptions

    if (sortKey && sortOrder) {
        queryOptions.order = {
            [sortKey]: sortOrder
        }
    }

    // if (search) {
    //     queryOptions.where = {
    //         name: ILike(`%${search}%`)
    //     }
    // }

    const accounts = await Account.findAndCount(queryOptions)

    return { accounts: accounts[0], total: accounts[1] }
}

export const getAccount = async (id: number) => {
    const account = await Account.findOneBy({ id })

    if (!account) {
        throw boom.notFound()
    }

    return account
}

export const openAccount = async (data: CreateAccountOptions) => {
    const { initialBalance, openingDatetime, userId } = data
    const user = await getUser(userId)
    const account = new Account()

    account.initialBalance = initialBalance
    account.openingDatetime = openingDatetime.toString()
    account.user = user

    await account.save()

    if (!account) {
        throw boom.badData('No se puede aperturar la caja')
    }
    
    return account
}

export const closeAccount = async (id: number, changes: CloseAccountOptions) => {
    const { closingDatetime, unbalance, observation } = changes
    const account = await getAccount(id)
    account.closingDatetime = closingDatetime.toString()
    account.unbanlance = unbalance
    account.observation = observation
    account.status = AccountStatus.CLOSING

    await account.save()

    if (!account) {
        throw boom.badData('No se puede cerrar la caja')
    }

    return account
}

export const deleteAccount = async (id: number) => {
    const account = await getAccount(id)
    await account.remove()

    return account
}