import { AccountStatus } from '@/db/entities/CommonOptions'
import { z as Zod } from 'zod'

const name = Zod.string({
    required_error: 'El nombre es obligatioria',
    invalid_type_error: 'El  nombre de ser cadena'
}).max(50, { message: 'Maximo 50 caracteres'})

const initialBalance = Zod.number({
    required_error: 'Balance inicial es requerido',
    invalid_type_error: 'Balance inicial debe ser numero'
})
    .nonnegative({ message: 'El inicial no puede ser positivo' })

const availableBalance = Zod.number({
    required_error: 'El balance es requerido',
    invalid_type_error: 'El balance debe ser numero'
})
    .nonnegative({ message: 'El balance no puede ser negativo' })

const status = Zod.nativeEnum(AccountStatus, {
    required_error: 'Status es requerido',
    invalid_type_error: 'Status no es valido'
})

export const createAccountSchema = Zod.object({
    name,
    initialBalance,
})

export const updateAccountSchema = Zod.object({
    name: name.optional(),
    status: status.optional()
})

export type CreateAccountOptions = Zod.infer<typeof createAccountSchema>
export type CloseAccountOptions = Zod.infer<typeof updateAccountSchema>