import { Router, Request, Response, NextFunction } from 'express'
import passport from 'passport'
import { success } from '@/helpers/responseHandler'
import { signToken } from "./authController"
import { bodyValidator } from '@/helpers/validatorHandler'
import { signInUserSchema } from './authSchema'

const router = Router()

router.post('/sign-in',
    bodyValidator(signInUserSchema),
    passport.authenticate('local', { session: false }),
    async (req: Request, res: Response, next: NextFunction) => {
        try {
            const user = req.user
            
            const token = signToken(user)
            success(res, token, 'Autenticación exitoso')
        } catch (error) {
            next(error)
        }
    }
)

export default router