import { FindManyOptions, ILike } from 'typeorm'
import boom from '@hapi/boom'
import { Brand } from '@/db/entities/Brand'
import { CreateBrandOptions, UpdateBrandOptions } from './brandSchema'
import { QueryOptions } from '@/@types/common'

export const getBrands = async (query: QueryOptions) => {
    const { skip, take, search, sortKey, sortOrder } = query
    const queryOptions = {
        order: {
            id: 'DESC'
        },
        skip: skip,
        take: take
    } as FindManyOptions

    if (sortKey && sortOrder) {
        queryOptions.order = {
            [sortKey]: sortOrder
        }
    }

    if (search) {
        queryOptions.where = {
            name: ILike(`%${search}%`)
        }
    }

    const brands = await Brand.findAndCount(queryOptions)

    return { brands: brands[0], total: brands[1] }
}

export const getBrand = async (id: number) => {
    const brand = await Brand.findOneBy({ id })

    if (!brand) {
        throw boom.notFound('No existe marca')
    }

    return brand
}

export const createBrand = async (data: CreateBrandOptions) => {
    const { name } = data
    const brand = new Brand()

    brand.name = name

    await brand.save()

    if (!brand) {
        throw boom.badData('No se puede crear la marca')
    }
    
    return brand
}

export const updateCategoty = async (id: number, changes: UpdateBrandOptions) => {
    const { name } = changes
    const brand = await getBrand(id)
    brand.name = name

    await brand.save()

    if (!brand) {
        throw boom.badData('No se puede actualizar la marca')
    }

    return brand
}

export const deleteBrand = async (id: number) => {
    const brand = await getBrand(id)
    await brand.remove()

    return brand
}