import { FindManyOptions, ILike } from 'typeorm'
import boom from '@hapi/boom'
import { Category } from '@/db/entities/Category'
import { CreateCategoryOptions, UpdateCategoryOptions } from './categorySchema'
import { QueryOptions } from '@/@types/common'

export const getCategories = async (query: QueryOptions) => {
    const { skip, take, search, sortKey, sortOrder } = query
    const queryOptions = {
        order: {
            id: 'DESC'
        },
        skip: skip,
        take: take
    } as FindManyOptions

    if (sortKey && sortOrder) {
        queryOptions.order = {
            [sortKey]: sortOrder
        }
    }

    if (search) {
        queryOptions.where = {
            name: ILike(`%${search}%`)
        }
    }

    const categories = await Category.findAndCount(queryOptions)

    return { categories: categories[0], total: categories[1] }
}

export const getCategory = async (id: number) => {
    const category = await Category.findOneBy({ id })

    if (!category) {
        throw boom.notFound('Categoría no existe')
    }

    return category
}

export const createCategory = async (data: CreateCategoryOptions) => {
    const { name } = data

    const category = new Category()
    category.name = name

    await category.save()

    if (category) {
        return category
    } else {
        throw boom.badData('No se puede crear categoría')
    }
}

export const updateCategoty = async (id: number, changes: UpdateCategoryOptions) => {
    const { name } = changes
    const category = await getCategory(id)
    category.name = name

    await category.save()

    return category
}

export const deleteCategory = async (id: number) => {
    const category = await getCategory(id)
    await category.remove()

    return category
}