import { FindManyOptions, ILike } from 'typeorm'
import boom from '@hapi/boom'
import { Concept } from '@/db/entities/Concept'
import { CreateConceptOptions, UpdateConceptOptions } from './conceptSchema'
import { QueryCommonOptions } from '@/utils/commonSchema'

export const getConcepts = async (query: QueryCommonOptions) => {
    const { skip, take, search, sortKey, sortOrder } = query
    const queryOptions = {
        order: {
            id: 'DESC'
        },
        skip: skip,
        take: take
    } as FindManyOptions

    if (sortKey && sortOrder) {
        queryOptions.order = {
            [sortKey]: sortOrder
        }
    }

    if (search) {
        queryOptions.where = {
            name: ILike(`%${search}%`)
        }
    }

    const concepts = await Concept.findAndCount(queryOptions)

    return { concepts: concepts[0], total: concepts[1] }
}

export const getConcept = async (id: number) => {
    const concept = await Concept.findOneBy({ id })

    if (!concept) {
        throw boom.notFound('No existe concepto')
    }

    return concept
}

export const createConcept = async (data: CreateConceptOptions) => {
    const { name } = data
    const concept = new Concept()

    concept.name = name

    await concept.save()

    if (!concept) {
        throw boom.badData('No se puede crear el concepto')
    }
    
    return concept
}

export const updateCategoty = async (id: number, changes: UpdateConceptOptions) => {
    const { name } = changes
    const concept = await getConcept(id)
    concept.name = name

    await concept.save()

    if (!concept) {
        throw boom.badData('No se puede actualizar el concepto')
    }

    return concept
}

export const deleteConcept = async (id: number) => {
    const concept = await getConcept(id)
    await concept.remove()

    return concept
}