import { Router, Request, Response, NextFunction } from 'express'
import { getConcepts, getConcept, createConcept, deleteConcept, updateCategoty } from './conceptController'
import { createConceptSchema, updateConceptSchema } from './conceptSchema'
import { queryCommonSchema, paramsCommonSchema } from '@/utils/commonSchema'
import { bodyValidator, queryValidator, paramsValidator } from '@/helpers/validatorHandler'
import { success } from '@/helpers/responseHandler'

const router = Router()

router.get('/',
    queryValidator(queryCommonSchema),
    async (req: Request, res: Response, next: NextFunction) => {
        try {
            const concepts = await getConcepts(req.query)
            success(res, concepts)
        } catch (error) {
            next(error)
        }
    }
)

router.get('/:id',
    paramsValidator(paramsCommonSchema),
    async (req: Request, res: Response, next: NextFunction) => {
        try {
            const conceptId = Number(req.params.id)
            const concept = await getConcept(conceptId)
            success(res, { concept }, 'Concepto encontrado con éxito')
        } catch (error) {
            next(error)
        }
    }
)

router.post('/',
    bodyValidator(createConceptSchema),
    async (req: Request, res: Response, next: NextFunction) => {
        try {
            const concept = await createConcept(req.body)
            success(res, { concept }, 'Concepto creado con éxito', 201)
        } catch (error) {
            next(error)
        }
    }
)

router.put('/:id',
    paramsValidator(paramsCommonSchema),
    bodyValidator(updateConceptSchema),
    async (req: Request, res: Response, next: NextFunction) => {
        try {
            const conceptId = Number(req.params.id)
            const concept = await updateCategoty(conceptId, req.body)
            success(res, { concept }, 'Concepto actualizado con éxito', 201)
        } catch (error) {
            next(error)
        }
    }
)

router.delete('/:id',
    paramsValidator(paramsCommonSchema),
    async (req: Request, res: Response, next: NextFunction) => {
        try {
            const conceptId = Number(req.params.id)
            await deleteConcept(conceptId)
            success(res, {}, 'Concepto eliminado con éxito')
        } catch (error) {
            next(error)
        }
    }
)

export default router