import { z as Zod } from 'zod'
import { DocumentType } from '@/db/Common'

const name = Zod.string({
    required_error: 'campo obligatorio',
    invalid_type_error: 'debe ser texto'
})
    .min(7, { message: 'mínimo 7 caracteres' })
    .max(100, { message: 'máximo 100 caracteres' })

const documentType = Zod.nativeEnum(DocumentType, {
    required_error: 'campo obligatorio',
    invalid_type_error: 'valor incorrecto'
})

const documentNumber = Zod.string({
    required_error: 'campo obligatorio',
    invalid_type_error: 'valor incorrecto'
}).regex(/^(\d{8}|\d{11})$/, { message: 'número no válido' })

const address = Zod.string({
    invalid_type_error: 'valor incorrecto'
})

const phoneNumber = Zod.string({
    invalid_type_error: 'valor incorrecto'
})
    .regex(/^9\d{8}$/, { message: 'número no válido' })

const email = Zod.string({
    invalid_type_error: 'valor incorrecto'
}).email({ message: 'email no válido' })

export const createCustomerSchema = Zod.object({
    name,
    documentType,
    documentNumber,
    address: address.optional(),
    phoneNumber: phoneNumber.optional(),
    email: email.optional()
})

export const updateCustomerSchema = Zod.object({
    name: name.optional(),
    documentType: documentType.optional(),
    documentNumber: documentNumber.optional(),
    address: address.optional(),
    phoneNumber: phoneNumber.optional(),
    email: email.optional()
})

export type CreateCustomerOptions = Zod.infer<typeof createCustomerSchema>
export type UpdateCustomerOptions = Zod.infer<typeof updateCustomerSchema>