import { z as Zod } from 'zod'

const description = Zod.string({
    required_error: 'Descripcion es requerido',
    invalid_type_error: 'Descripcion debe ser texto'
})
    .min(6, { message: 'Descripcion demasiado corto' })
    .max(200, { message: 'Descripcion demasiado largo' })

const amount = Zod.number({
    required_error: 'Monto es requerido',
    invalid_type_error: 'Monto debe ser numero'
})
    .positive({ message: 'Monto debe ser positivo' })

const conceptId = Zod.number({
    required_error: 'ID de concepto es requerido',
    invalid_type_error: 'ID de cocepto debe ser número'
})

export const createExpenseSchema = Zod.object({
    description,
    amount,
    conceptId
})

export const updateExpenseSchema = Zod.object({
    description: description.optional(),
    amount: amount.optional(),
    conceptId: conceptId.optional(),
})

export type CreateExpense = Zod.infer<typeof createExpenseSchema>
export type UpdateExpense = Zod.infer<typeof updateExpenseSchema>