import { Router, Request, Response, NextFunction } from 'express'
import { getProducts, getProduct, createProduct, deleteProduct, updateCategoty, getProductsByCategory } from './productController'
import { createProductSchema, updateProductSchema } from './productSchema'
import { queryCommonSchema, paramsCommonSchema } from '@/utils/commonSchema'
import { bodyValidator, queryValidator, paramsValidator } from '@/helpers/validatorHandler'
import { success } from '@/helpers/responseHandler'
import { queryParser } from '@/utils/queryParser'

const router = Router()

router.get('/',
    queryValidator(queryCommonSchema),
    async (req: Request, res: Response, next: NextFunction) => {
        try {
            const query = queryParser(req.query)
            const products = await getProducts(query)
            success(res, products)
        } catch (error) {
            next(error)
        }
    }
)

router.get('/:id',
    paramsValidator(paramsCommonSchema),
    async (req: Request, res: Response, next: NextFunction) => {
        try {
            const productId = Number(req.params.id)
            const product = await getProduct(productId)
            success(res, { product }, 'Producto encontrado con éxito3')
        } catch (error) {
            next(error)
        }
    }
)

// router.post('/:categorySlug/:subcategorySlug',
//     paramsValidator(paramsCommonSchema),
//     queryValidator(queryCommonSchema),
//     async (req: Request, res: Response, next: NextFunction) => {
//         try {
//             const categorySlug = req.params.categorySlug
//             const subcategorySlug = req.params.subcategorySlug
//             const products = await getProductsByCategory(categorySlug, subcategorySlug, req.query, req.body)
//             success(res, products)
//         } catch (error) {
//             next(error)
//         }
//     }
// )

router.post('/',
    bodyValidator(createProductSchema),
    async (req: Request, res: Response, next: NextFunction) => {
        try {
            await createProduct(req.body)
            success(res, {}, 'Producto creado con éxito', 201)
        } catch (error) {
            next(error)
        }
    }
)

router.put('/:id',
    paramsValidator(paramsCommonSchema),
    bodyValidator(updateProductSchema),
    async (req: Request, res: Response, next: NextFunction) => {        
        try {
            const productId = Number(req.params.id)
            await updateCategoty(productId, req.body)
            success(res, {}, 'Producto actualizado con éxito', 201)
        } catch (error) {
            next(error)
        }
    }
)

router.delete('/:id',
    paramsValidator(paramsCommonSchema),
    async (req: Request, res: Response, next: NextFunction) => {
        try {
            const productId = Number(req.params.id)
            await deleteProduct(productId)
            success(res, {}, 'Productos eliminada con éxito')
        } catch (error) {
            next(error)
        }
    }
)

export default router