import { z as Zod } from 'zod'

const sku = Zod.string({
    required_error: 'Código es requerido',
    invalid_type_error: 'Código debe ser texto'
})
    .min(3, 'Código demasiado corto')
    .max(10, 'Código demasiado lago')

const name = Zod.string({
    required_error: 'Nombre es requerido',
    invalid_type_error: 'Nombre debe ser texto'
})
    .min(2, { message: 'Nombre demasiado corto' })
    .max(200, { message: 'Nombre demasiado largo' })

const cost = Zod.number({
    required_error: 'Costo es requerido',
    invalid_type_error: 'Costo debe ser numero'
})
    .positive({ message: 'Costo debe ser positivo' })

const utility = Zod.number({
    required_error: 'Costo es requerido',
    invalid_type_error: 'Costo debe ser numero'
})
    .nonnegative({ message: 'Utilidad no puede ser negativo' })
    .max(100, { message: 'Utilidad maximo es 100%' })

const price = Zod.number({
    required_error: 'Precio es requerido',
    invalid_type_error: 'Precio debe ser numero'
})
    .positive({ message: 'Precio debe ser positivo' })

const stock = Zod.number({
    required_error: 'Stock es requerido',
    invalid_type_error: 'Stock debe ser numero'
})
    .nonnegative({ message: 'Stock no puede ser negativo' })
    .int({ message: 'Stocke debe ser entero' })

const stockMin = Zod.number({
    required_error: 'Stock es requerido',
    invalid_type_error: 'Stock debe ser numero'
})
    .positive({ message: 'Stock no puede ser negativo' })
    .int({ message: 'Stocke debe ser entero' })

const bulkDiscount = Zod.number({
    required_error: 'Descuento es requerido',
    invalid_type_error: 'Descuento debe ser numero'
})
    .nonnegative({ message: 'Descuento no puede ser negativo' })
    .max(100, { message: 'Descuento maximo es 100%' })

const unitId = Zod.number({
    required_error: 'Unidad ID es requerido',
    invalid_type_error: 'Unidad ID debe ser número'
})

const subcategoryId = Zod.number({
    required_error: 'Subcategoría ID es requerido',
    invalid_type_error: 'Subcategoría ID debe ser número'
})

const brandId = Zod.number({
    required_error: 'Marca ID es requerido',
    invalid_type_error: 'Marca ID debe ser número'
})

const imageUrl = Zod.string()

export const createProductSchema = Zod.object({
    sku,
    name,
    cost,
    utility,
    price,
    stock,
    stockMin,
    bulkDiscount,
    unitId,
    subcategoryId,
    brandId,
    imageUrl: imageUrl.optional()
})

export const updateProductSchema = Zod.object({
    sku: sku.optional(),
    name: name.optional(),
    cost: cost.optional(),
    price: price.optional(),
    utility: utility.optional(),
    stock: stock.optional(),
    stockMin: stockMin.optional(),
    bulkDiscount: bulkDiscount.optional(),
    unitId: unitId.optional(),
    subcategoryId: subcategoryId.optional(),
    brandId: brandId.optional(),
    imageUrl: imageUrl.optional()
})

export type CreateProductOptions = Zod.infer<typeof createProductSchema>
export type UpdateProductOptions = Zod.infer<typeof updateProductSchema>