import { InvoceTypes } from '@/db/Common'
import { z as Zod } from 'zod'

const quantity = Zod.number({
    required_error: 'quantity requerido',
    invalid_type_error: 'quantity incorrecto'
})
    .min(1, 'quantity mínimo aceptado 1')

const unitPrice = Zod.number({
    required_error: 'unitPrice requerido',
    invalid_type_error: 'unitPrice incorrecto'
})
    .positive({ message: 'unitPrice incorrecto' })

const customerId = Zod.number({
    required_error: 'customerId requerido',
    invalid_type_error: 'customerId incorrecto'
})

const saleAmount = Zod.number({
    required_error: 'saleAmount requerido',
    invalid_type_error: 'saleAmount incorrecto'
})
    .positive({ message: 'saleAmount incorrecto' })

const igv = Zod.number({
    required_error: 'igv requerido',
    invalid_type_error: 'igv incorrecto'
})
    .positive({ message: 'saleAmount incorrecto' })

const invoceType = Zod.nativeEnum(InvoceTypes, {
    required_error: 'invoceType requerido',
    invalid_type_error: 'invoceType incorrecto'
})

const itemsSchema = Zod.object({
    productId: Zod.number(),
    quantity,
    unitPrice
})

export const createSaleSchema = Zod.object({
    invoceType,
    customerId,
    saleAmount,
    igv,
    items: Zod.array(itemsSchema).min(1, 'items mínimo 1'),
})

export type CreateSaleOptions = Zod.infer<typeof createSaleSchema>
export type ItemSaleOptions = Zod.infer<typeof itemsSchema>