import { UserRoles } from '@/db/Common'
import { z as Zod } from 'zod'

const username = Zod.string({
    required_error: 'Nombre de usuario es requerido',
    invalid_type_error: 'Nombre de usuario debe ser texto'
})
    .min(3, { message: 'Nombre de usuario demasiado corto' })
    .max(20, { message: 'Nombre de usuario demasiado largo' })

const password = Zod.string({
    required_error: 'Contraseña es requerido',
    invalid_type_error: 'Contraseña debe ser texto'
})
    .min(6, { message: 'Contraseña demasiado corto' })
    .max(30, { message: 'Contraseña demasiado larga' })

const fullname = Zod.string({
    required_error: 'Nombre es requerido',
    invalid_type_error: 'Nombre debe ser texto'
})

const active = Zod.boolean({
    invalid_type_error: 'Estado debe ser booleano',
})

const role = Zod.nativeEnum(UserRoles, {
    required_error: ' Rol es requerido',
    invalid_type_error: 'Rol no válido'
})

export const createUserScheme = Zod.object({
    username,
    password,
    fullname,
    active: active.optional(),
    role
})

export const updateUserScheme = Zod.object({
    username: username.optional(),
    password: password.optional(),
    fullname: fullname.optional(),
    active: active.optional(),
    role: role.optional()
})

export type CreateUserOptions = Zod.infer<typeof createUserScheme>
export type UpdateUserOptions = Zod.infer<typeof updateUserScheme>