import { Router, Application } from 'express'
import passport from 'passport'
import { checkRoles } from '@/helpers/authHandler'
import userRoutes from '@/modules/users/userRoutes'
import authRoutes from '@/modules/auth/authRoutes'
import categoryRoutes from '@/modules/categories/categoryRoutes'
import subcategoryRoutes from '@/modules/subcategories/subcategoryRoutes'
import brandRoutes from '@/modules/brands/brandRoutes'
import productRoutes from '@/modules/products/productRoutes'
import unitRoutes from '@/modules/units/unitRoutes'
import customerRoutes from '@/modules/customers/customerRoutes'
import cashierRoutes from '@/modules/cashiers/cashierRoutes'
import conceptRoutes from '@/modules/concepts/conceptRoutes'
import expenseRoutes from '@/modules/expenses/expenseRoutes'
import saleRoutes from '@/modules/sales/saleRoutes'
import { UserRoles } from '@/db/Common'



const handleRoutes = (app: Application) => {
    const router = Router()

    app.use('/api/v1/', router)

    router.use('/users', passport.authenticate('jwt', { session: false }), checkRoles(UserRoles.ADMIN), userRoutes)
    router.use('/auth', authRoutes)
    router.use('/categories', passport.authenticate('jwt', { session: false }), checkRoles(UserRoles.ADMIN, UserRoles.ALMACENERO, UserRoles.GERENTE, UserRoles.CAJERO), categoryRoutes)
    router.use('/subcategories', passport.authenticate('jwt', { session: false }), checkRoles(UserRoles.ADMIN, UserRoles.ALMACENERO, UserRoles.GERENTE, UserRoles.CAJERO), subcategoryRoutes)
    router.use('/brands', passport.authenticate('jwt', { session: false }), checkRoles(UserRoles.ADMIN, UserRoles.ALMACENERO, UserRoles.GERENTE, UserRoles.CAJERO), brandRoutes)
    router.use('/products', passport.authenticate('jwt', { session: false }), checkRoles(UserRoles.ADMIN, UserRoles.ALMACENERO, UserRoles.GERENTE, UserRoles.CAJERO), productRoutes)
    router.use('/units', passport.authenticate('jwt', { session: false }), checkRoles(UserRoles.ADMIN, UserRoles.ALMACENERO, UserRoles.GERENTE, UserRoles.CAJERO), unitRoutes)
    router.use('/customers', passport.authenticate('jwt', { session: false }), checkRoles(UserRoles.ADMIN, UserRoles.GERENTE, UserRoles.CAJERO), customerRoutes)
    router.use('/cashiers', passport.authenticate('jwt', { session: false }), checkRoles(UserRoles.ADMIN, UserRoles.GERENTE, UserRoles.CAJERO), cashierRoutes)
    router.use('/concepts', passport.authenticate('jwt', { session: false }), checkRoles(UserRoles.ADMIN, UserRoles.CAJERO), conceptRoutes)
    router.use('/expenses', passport.authenticate('jwt', { session: false }), checkRoles(UserRoles.ADMIN, UserRoles.CAJERO), expenseRoutes)
    router.use('/sales', passport.authenticate('jwt', { session: false }), checkRoles(UserRoles.ADMIN, UserRoles.CAJERO, UserRoles.GERENTE), saleRoutes)
}

export default handleRoutes